@@ -25,3 +25,18 @@
 #' A tibble that shows the format a tibble should take when it is
 #'   submitted to a individual `scoring` function.
 "indiv"
+
+#' Example Data for Non-BIBD Aggregate-Level Best-Worst Scaling
+#'
+#' @description
+#' A tibble that shows the format a tibble should take when it is
+#'   submitted to an aggregate scoring function that is NOT ae_mnl(), which
+#'   assumes a balanced incomplete block design (BIBD).
+"agg"
+
+#' Example Data Used in Vignettes
+#'
+#' @description
+#' A tibble that shows the format a tibble should take when it is
+#'   submitted to a individual `scoring` function.
+"vdata"
